.. _installation.rst

Installation
================

Installing the latest code from github
----------------------------------------
::

    git clone https://github.com/simpsonlab/preqc-lr.git
    python setup.py install

Installing dependencies with pip
------------------------------------
::

    pip install preqc-lr

This will install the following packages with all their dependencies:

* matplotlib
* BioPython

Additionally, you will need python2.7.11 and the `OpenBLAS library <https://www.openblas.net>`_.
